summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJoey Castillo <jose.castillo@gmail.com>2021-10-16 13:14:52 -0400
committerJoey Castillo <jose.castillo@gmail.com>2021-10-16 13:14:52 -0400
commitd5ac4cb71b4e328a27e26843cfdc6719b152ac7d (patch)
tree5e6d916c6848c912ae8cbc4d2ff799728103d6a7
parente8461984d60a80841a5f4b219358cc20567114f8 (diff)
downloadSensor-Watch-d5ac4cb71b4e328a27e26843cfdc6719b152ac7d.tar.gz
Sensor-Watch-d5ac4cb71b4e328a27e26843cfdc6719b152ac7d.tar.bz2
Sensor-Watch-d5ac4cb71b4e328a27e26843cfdc6719b152ac7d.zip
widgets are now watch faces
-rwxr-xr-xmovement/make/Makefile20
-rw-r--r--movement/movement.c40
-rw-r--r--movement/movement.h34
-rw-r--r--movement/movement_config.h18
-rw-r--r--movement/watch_faces/clock/simple_clock_face.c (renamed from movement/widgets/clock/simple_clock_widget.c)20
-rw-r--r--movement/watch_faces/clock/simple_clock_face.h20
-rw-r--r--movement/watch_faces/complications/pulseometer_face.c (renamed from movement/widgets/complications/pulseometer_widget.c)22
-rw-r--r--movement/watch_faces/complications/pulseometer_face.h24
-rw-r--r--movement/watch_faces/settings/preferences_face.c (renamed from movement/widgets/settings/preferences_widget.c)22
-rw-r--r--movement/watch_faces/settings/preferences_face.h18
-rw-r--r--movement/watch_faces/settings/set_time_face.c (renamed from movement/widgets/settings/set_time_widget.c)24
-rw-r--r--movement/watch_faces/settings/set_time_face.h18
-rw-r--r--movement/widgets/clock/simple_clock_widget.h20
-rw-r--r--movement/widgets/complications/pulseometer_widget.h24
-rw-r--r--movement/widgets/settings/preferences_widget.h18
-rw-r--r--movement/widgets/settings/set_time_widget.h18
16 files changed, 180 insertions, 180 deletions
diff --git a/movement/make/Makefile b/movement/make/Makefile
index 35b80079..8b29fba4 100755
--- a/movement/make/Makefile
+++ b/movement/make/Makefile
@@ -7,26 +7,26 @@ include $(TOP)/make.mk
# INCLUDES += \
# -I../ \
# -I../drivers/ \
-# -I../widgets/fitness/
+# -I../watch_faces/fitness/
INCLUDES += \
-I../ \
- -I../widgets/ \
- -I../widgets/clock/ \
- -I../widgets/settings/ \
- -I../widgets/complications/ \
+ -I../watch_faces/ \
+ -I../watch_faces/clock/ \
+ -I../watch_faces/settings/ \
+ -I../watch_faces/complications/ \
# If you add any other source files you wish to compile, add them after ../app.c
# Note that you will need to add a backslash at the end of any line you wish to continue, i.e.
# SRCS += \
# ../movement.c \
# ../drivers/lis2dh.c \
-# ../widgets/fitness/step_count_widget.c
+# ../watch_faces/fitness/step_count_face.c
SRCS += \
../movement.c \
- ../widgets/clock/simple_clock_widget.c \
- ../widgets/settings/preferences_widget.c \
- ../widgets/settings/set_time_widget.c \
- ../widgets/complications/pulseometer_widget.c \
+ ../watch_faces/clock/simple_clock_face.c \
+ ../watch_faces/settings/preferences_face.c \
+ ../watch_faces/settings/set_time_face.c \
+ ../watch_faces/complications/pulseometer_face.c \
# Leave this line at the bottom of the file; it has all the targets for making your project.
include $(TOP)/rules.mk
diff --git a/movement/movement_config.h b/movement/movement_config.h
index 49f342ca..41066d19 100644
--- a/movement/movement_config.h
+++ b/movement/movement_config.h
@@ -1,17 +1,17 @@
#ifndef MOVEMENT_CONFIG_H_
#define MOVEMENT_CONFIG_H_
-#include "simple_clock_widget.h"
-#include "preferences_widget.h"
-#include "set_time_widget.h"
-#include "pulseometer_widget.h"
+#include "simple_clock_face.h"
+#include "preferences_face.h"
+#include "set_time_face.h"
+#include "pulseometer_face.h"
-#define MOVEMENT_NUM_WIDGETS 3
+#define MOVEMENT_NUM_FACES 3
-WatchWidget widgets[MOVEMENT_NUM_WIDGETS] = {
- simple_clock_widget,
- preferences_widget,
- set_time_widget,
+WatchFace watch_faces[MOVEMENT_NUM_FACES] = {
+ simple_clock_face,
+ preferences_face,
+ set_time_face,
};
diff --git a/movement/widgets/clock/simple_clock_widget.c b/movement/watch_faces/clock/simple_clock_face.c
index 22218860..97067b0f 100644
--- a/movement/widgets/clock/simple_clock_widget.c
+++ b/movement/watch_faces/clock/simple_clock_face.c
@@ -1,14 +1,14 @@
#include <stdlib.h>
-#include "simple_clock_widget.h"
+#include "simple_clock_face.h"
#include "watch.h"
-void simple_clock_widget_setup(LauncherSettings *settings, void ** context_ptr) {
+void simple_clock_face_setup(LauncherSettings *settings, void ** context_ptr) {
(void) settings;
// the only context we need is the timestamp of the previous tick.
if (*context_ptr == NULL) *context_ptr = malloc(sizeof(uint32_t));
}
-void simple_clock_widget_activate(LauncherSettings *settings, void *context) {
+void simple_clock_face_activate(LauncherSettings *settings, void *context) {
if (settings->bit.clock_mode_24h) {
watch_set_indicator(WATCH_INDICATOR_24H);
}
@@ -17,8 +17,8 @@ void simple_clock_widget_activate(LauncherSettings *settings, void *context) {
*((uint32_t *)context) = 0xFFFFFFFF;
}
-bool simple_clock_widget_loop(LauncherEvent event, LauncherSettings *settings, void *context) {
- printf("simple_clock_widget_loop\n");
+bool simple_clock_face_loop(LauncherEvent event, LauncherSettings *settings, void *context) {
+ printf("simple_clock_face_loop\n");
const char weekdays[7][3] = {"SA", "SU", "MO", "TU", "WE", "TH", "FR"};
char buf[11];
uint8_t pos;
@@ -55,15 +55,15 @@ bool simple_clock_widget_loop(LauncherEvent event, LauncherSettings *settings, v
}
pos = 0;
if (event.event_type == EVENT_SCREENSAVER) {
- sprintf(buf, "%s%2d%2d%02d ", weekdays[simple_clock_widget_get_weekday(date_time.unit.year, date_time.unit.month, date_time.unit.day)], date_time.unit.day, date_time.unit.hour, date_time.unit.minute);
+ sprintf(buf, "%s%2d%2d%02d ", weekdays[simple_clock_face_get_weekday(date_time.unit.year, date_time.unit.month, date_time.unit.day)], date_time.unit.day, date_time.unit.hour, date_time.unit.minute);
} else {
- sprintf(buf, "%s%2d%2d%02d%02d", weekdays[simple_clock_widget_get_weekday(date_time.unit.year, date_time.unit.month, date_time.unit.day)], date_time.unit.day, date_time.unit.hour, date_time.unit.minute, date_time.unit.second);
+ sprintf(buf, "%s%2d%2d%02d%02d", weekdays[simple_clock_face_get_weekday(date_time.unit.year, date_time.unit.month, date_time.unit.day)], date_time.unit.day, date_time.unit.hour, date_time.unit.minute, date_time.unit.second);
}
}
watch_display_string(buf, pos);
break;
case EVENT_MODE_BUTTON_UP:
- movement_move_to_next_widget();
+ movement_move_to_next_face();
return false;
case EVENT_LIGHT_BUTTON_UP:
movement_illuminate_led();
@@ -77,12 +77,12 @@ bool simple_clock_widget_loop(LauncherEvent event, LauncherSettings *settings, v
return true;
}
-void simple_clock_widget_resign(LauncherSettings *settings, void *context) {
+void simple_clock_face_resign(LauncherSettings *settings, void *context) {
(void) settings;
(void) context;
}
-uint8_t simple_clock_widget_get_weekday(uint16_t year, uint16_t month, uint16_t day) {
+uint8_t simple_clock_face_get_weekday(uint16_t year, uint16_t month, uint16_t day) {
year += 20;
if (month <= 2) {
month += 12;
diff --git a/movement/watch_faces/clock/simple_clock_face.h b/movement/watch_faces/clock/simple_clock_face.h
new file mode 100644
index 00000000..59201a1f
--- /dev/null
+++ b/movement/watch_faces/clock/simple_clock_face.h
@@ -0,0 +1,20 @@
+#ifndef SIMPLE_CLOCK_FACE_H_
+#define SIMPLE_CLOCK_FACE_H_
+
+#include "movement.h"
+
+void simple_clock_face_setup(LauncherSettings *settings, void ** context_ptr);
+void simple_clock_face_activate(LauncherSettings *settings, void *context);
+bool simple_clock_face_loop(LauncherEvent event, LauncherSettings *settings, void *context);
+void simple_clock_face_resign(LauncherSettings *settings, void *context);
+
+uint8_t simple_clock_face_get_weekday(uint16_t day, uint16_t month, uint16_t year);
+
+#define simple_clock_face { \
+ simple_clock_face_setup, \
+ simple_clock_face_activate, \
+ simple_clock_face_loop, \
+ simple_clock_face_resign, \
+}
+
+#endif // FAKE_FACE_H_ \ No newline at end of file
diff --git a/movement/widgets/complications/pulseometer_widget.c b/movement/watch_faces/complications/pulseometer_face.c
index 6384685a..e38153d6 100644
--- a/movement/widgets/complications/pulseometer_widget.c
+++ b/movement/watch_faces/complications/pulseometer_face.c
@@ -1,23 +1,23 @@
#include <stdlib.h>
#include <string.h>
-#include "pulseometer_widget.h"
+#include "pulseometer_face.h"
#include "watch.h"
-#define PULSOMETER_WIDGET_FREQUENCY_FACTOR (4ul) // refresh rate will be 2 to this power Hz (0 for 1 Hz, 2 for 4 Hz, etc.)
-#define PULSOMETER_WIDGET_FREQUENCY (1 << PULSOMETER_WIDGET_FREQUENCY_FACTOR)
+#define PULSOMETER_FACE_FREQUENCY_FACTOR (4ul) // refresh rate will be 2 to this power Hz (0 for 1 Hz, 2 for 4 Hz, etc.)
+#define PULSOMETER_FACE_FREQUENCY (1 << PULSOMETER_FACE_FREQUENCY_FACTOR)
-void pulseometer_widget_setup(LauncherSettings *settings, void ** context_ptr) {
+void pulseometer_face_setup(LauncherSettings *settings, void ** context_ptr) {
(void) settings;
if (*context_ptr == NULL) *context_ptr = malloc(sizeof(PulsometerState));
}
-void pulseometer_widget_activate(LauncherSettings *settings, void *context) {
+void pulseometer_face_activate(LauncherSettings *settings, void *context) {
(void) settings;
memset(context, 0, sizeof(PulsometerState));
}
-bool pulseometer_widget_loop(LauncherEvent event, LauncherSettings *settings, void *context) {
- printf("pulseometer_widget_loop\n");
+bool pulseometer_face_loop(LauncherEvent event, LauncherSettings *settings, void *context) {
+ printf("pulseometer_face_loop\n");
(void) settings;
PulsometerState *pulsometer_state = (PulsometerState *)context;
char buf[14];
@@ -44,7 +44,7 @@ bool pulseometer_widget_loop(LauncherEvent event, LauncherSettings *settings, vo
pulsometer_state->ticks = (pulsometer_state->ticks + 1) % 5;
} else {
if (pulsometer_state->measuring && pulsometer_state->ticks) {
- pulsometer_state->pulse = (int16_t)((30.0 * ((float)(60 << PULSOMETER_WIDGET_FREQUENCY_FACTOR) / (float)pulsometer_state->ticks)) + 0.5);
+ pulsometer_state->pulse = (int16_t)((30.0 * ((float)(60 << PULSOMETER_FACE_FREQUENCY_FACTOR) / (float)pulsometer_state->ticks)) + 0.5);
}
if (pulsometer_state->pulse > 240) {
watch_display_string(" Hi", 0);
@@ -58,7 +58,7 @@ bool pulseometer_widget_loop(LauncherEvent event, LauncherSettings *settings, vo
}
return false;
case EVENT_MODE_BUTTON_UP:
- movement_move_to_next_widget();
+ movement_move_to_next_face();
return false;
case EVENT_LIGHT_BUTTON_UP:
movement_illuminate_led();
@@ -67,7 +67,7 @@ bool pulseometer_widget_loop(LauncherEvent event, LauncherSettings *settings, vo
pulsometer_state->ticks = 0;
pulsometer_state->pulse = 0xFFFF;
pulsometer_state->measuring = true;
- movement_request_tick_frequency(PULSOMETER_WIDGET_FREQUENCY);
+ movement_request_tick_frequency(PULSOMETER_FACE_FREQUENCY);
break;
case EVENT_ALARM_BUTTON_UP:
case EVENT_ALARM_LONG_PRESS:
@@ -81,7 +81,7 @@ bool pulseometer_widget_loop(LauncherEvent event, LauncherSettings *settings, vo
return true;
}
-void pulseometer_widget_resign(LauncherSettings *settings, void *context) {
+void pulseometer_face_resign(LauncherSettings *settings, void *context) {
(void) settings;
(void) context;
}
diff --git a/movement/watch_faces/complications/pulseometer_face.h b/movement/watch_faces/complications/pulseometer_face.h
new file mode 100644
index 00000000..7b96259c
--- /dev/null
+++ b/movement/watch_faces/complications/pulseometer_face.h
@@ -0,0 +1,24 @@
+#ifndef PULSEOMETER_FACE_H_
+#define PULSEOMETER_FACE_H_
+
+#include "movement.h"
+
+typedef struct {
+ bool measuring;
+ int16_t pulse;
+ int16_t ticks;
+} PulsometerState;
+
+void pulseometer_face_setup(LauncherSettings *settings, void ** context_ptr);
+void pulseometer_face_activate(LauncherSettings *settings, void *context);
+bool pulseometer_face_loop(LauncherEvent event, LauncherSettings *settings, void *context);
+void pulseometer_face_resign(LauncherSettings *settings, void *context);
+
+#define pulseometer_face { \
+ pulseometer_face_setup, \
+ pulseometer_face_activate, \
+ pulseometer_face_loop, \
+ pulseometer_face_resign, \
+}
+
+#endif // PULSEOMETER_FACE_H_ \ No newline at end of file
diff --git a/movement/widgets/settings/preferences_widget.c b/movement/watch_faces/settings/preferences_face.c
index c4537329..f499e36f 100644
--- a/movement/widgets/settings/preferences_widget.c
+++ b/movement/watch_faces/settings/preferences_face.c
@@ -1,31 +1,31 @@
#include <stdlib.h>
-#include "preferences_widget.h"
+#include "preferences_face.h"
#include "watch.h"
-#define PREFERENCES_WIDGET_NUM_PREFEFENCES (5)
-const char preferences_widget_titles[PREFERENCES_WIDGET_NUM_PREFEFENCES][11] = {"CL ", "Bt Beep ", "SC ", "Lt grn ", "Lt red "};
+#define PREFERENCES_FACE_NUM_PREFEFENCES (5)
+const char preferences_face_titles[PREFERENCES_FACE_NUM_PREFEFENCES][11] = {"CL ", "Bt Beep ", "SC ", "Lt grn ", "Lt red "};
-void preferences_widget_setup(LauncherSettings *settings, void ** context_ptr) {
+void preferences_face_setup(LauncherSettings *settings, void ** context_ptr) {
(void) settings;
if (*context_ptr == NULL) *context_ptr = malloc(sizeof(uint8_t));
}
-void preferences_widget_activate(LauncherSettings *settings, void *context) {
+void preferences_face_activate(LauncherSettings *settings, void *context) {
(void) settings;
*((uint8_t *)context) = 0;
movement_request_tick_frequency(4); // we need to manually blink some pixels
}
-bool preferences_widget_loop(LauncherEvent event, LauncherSettings *settings, void *context) {
- printf("preferences_widget_loop\n");
+bool preferences_face_loop(LauncherEvent event, LauncherSettings *settings, void *context) {
+ printf("preferences_face_loop\n");
uint8_t current_page = *((uint8_t *)context);
switch (event.event_type) {
case EVENT_MODE_BUTTON_UP:
watch_set_led_off();
- movement_move_to_next_widget();
+ movement_move_to_next_face();
return false;
case EVENT_LIGHT_BUTTON_UP:
- current_page = (current_page + 1) % PREFERENCES_WIDGET_NUM_PREFEFENCES;
+ current_page = (current_page + 1) % PREFERENCES_FACE_NUM_PREFEFENCES;
*((uint8_t *)context) = current_page;
break;
case EVENT_ALARM_BUTTON_UP:
@@ -51,7 +51,7 @@ bool preferences_widget_loop(LauncherEvent event, LauncherSettings *settings, vo
break;
}
- watch_display_string((char *)preferences_widget_titles[current_page], 0);
+ watch_display_string((char *)preferences_face_titles[current_page], 0);
if (event.subsecond % 2) return current_page <= 2;
char buf[3];
@@ -112,7 +112,7 @@ bool preferences_widget_loop(LauncherEvent event, LauncherSettings *settings, vo
return true;
}
-void preferences_widget_resign(LauncherSettings *settings, void *context) {
+void preferences_face_resign(LauncherSettings *settings, void *context) {
(void) settings;
(void) context;
watch_set_led_off();
diff --git a/movement/watch_faces/settings/preferences_face.h b/movement/watch_faces/settings/preferences_face.h
new file mode 100644
index 00000000..218f99c2
--- /dev/null
+++ b/movement/watch_faces/settings/preferences_face.h
@@ -0,0 +1,18 @@
+#ifndef PREFERENCES_FACE_H_
+#define PREFERENCES_FACE_H_
+
+#include "movement.h"
+
+void preferences_face_setup(LauncherSettings *settings, void ** context_ptr);
+void preferences_face_activate(LauncherSettings *settings, void *context);
+bool preferences_face_loop(LauncherEvent event, LauncherSettings *settings, void *context);
+void preferences_face_resign(LauncherSettings *settings, void *context);
+
+#define preferences_face { \
+ preferences_face_setup, \
+ preferences_face_activate, \
+ preferences_face_loop, \
+ preferences_face_resign, \
+}
+
+#endif // PREFERENCES_FACE_H_ \ No newline at end of file
diff --git a/movement/widgets/settings/set_time_widget.c b/movement/watch_faces/settings/set_time_face.c
index 9464eb5b..36498611 100644
--- a/movement/widgets/settings/set_time_widget.c
+++ b/movement/watch_faces/settings/set_time_face.c
@@ -1,32 +1,32 @@
#include <stdlib.h>
-#include "set_time_widget.h"
+#include "set_time_face.h"
#include "watch.h"
-#define SET_TIME_WIDGET_NUM_SETTINGS (6)
-const char set_time_widget_titles[SET_TIME_WIDGET_NUM_SETTINGS][3] = {"HR", "MN", "SE", "YR", "MO", "DA"};
+#define SET_TIME_FACE_NUM_SETTINGS (6)
+const char set_time_face_titles[SET_TIME_FACE_NUM_SETTINGS][3] = {"HR", "MN", "SE", "YR", "MO", "DA"};
-void set_time_widget_setup(LauncherSettings *settings, void ** context_ptr) {
+void set_time_face_setup(LauncherSettings *settings, void ** context_ptr) {
(void) settings;
if (*context_ptr == NULL) *context_ptr = malloc(sizeof(uint8_t));
}
-void set_time_widget_activate(LauncherSettings *settings, void *context) {
+void set_time_face_activate(LauncherSettings *settings, void *context) {
(void) settings;
*((uint8_t *)context) = 0;
movement_request_tick_frequency(4);
}
-bool set_time_widget_loop(LauncherEvent event, LauncherSettings *settings, void *context) {
+bool set_time_face_loop(LauncherEvent event, LauncherSettings *settings, void *context) {
uint8_t current_page = *((uint8_t *)context);
const uint8_t days_in_month[12] = {31, 28, 31, 30, 31, 30, 30, 31, 30, 31, 30, 31};
watch_date_time date_time = watch_rtc_get_date_time();
switch (event.event_type) {
case EVENT_MODE_BUTTON_UP:
- movement_move_to_next_widget();
+ movement_move_to_next_face();
return false;
case EVENT_LIGHT_BUTTON_UP:
- current_page = (current_page + 1) % SET_TIME_WIDGET_NUM_SETTINGS;
+ current_page = (current_page + 1) % SET_TIME_FACE_NUM_SETTINGS;
*((uint8_t *)context) = current_page;
break;
case EVENT_ALARM_BUTTON_UP:
@@ -67,9 +67,9 @@ bool set_time_widget_loop(LauncherEvent event, LauncherSettings *settings, void
watch_set_colon();
if (settings->bit.clock_mode_24h) {
watch_set_indicator(WATCH_INDICATOR_24H);
- sprintf(buf, "%s %2d%02d%02d", set_time_widget_titles[current_page], date_time.unit.hour, date_time.unit.minute, date_time.unit.second);
+ sprintf(buf, "%s %2d%02d%02d", set_time_face_titles[current_page], date_time.unit.hour, date_time.unit.minute, date_time.unit.second);
} else {
- sprintf(buf, "%s %2d%02d%02d", set_time_widget_titles[current_page], (date_time.unit.hour % 12) ? (date_time.unit.hour % 12) : 12, date_time.unit.minute, date_time.unit.second);
+ sprintf(buf, "%s %2d%02d%02d", set_time_face_titles[current_page], (date_time.unit.hour % 12) ? (date_time.unit.hour % 12) : 12, date_time.unit.minute, date_time.unit.second);
if (date_time.unit.hour > 12) watch_set_indicator(WATCH_INDICATOR_PM);
else watch_clear_indicator(WATCH_INDICATOR_PM);
}
@@ -77,7 +77,7 @@ bool set_time_widget_loop(LauncherEvent event, LauncherSettings *settings, void
watch_clear_colon();
watch_clear_indicator(WATCH_INDICATOR_24H);
watch_clear_indicator(WATCH_INDICATOR_PM);
- sprintf(buf, "%s %2d%02d%02d", set_time_widget_titles[current_page], date_time.unit.year + 20, date_time.unit.month, date_time.unit.day);
+ sprintf(buf, "%s %2d%02d%02d", set_time_face_titles[current_page], date_time.unit.year + 20, date_time.unit.month, date_time.unit.day);
}
if (event.subsecond % 2) {
switch (current_page) {
@@ -101,7 +101,7 @@ bool set_time_widget_loop(LauncherEvent event, LauncherSettings *settings, void
return true;
}
-void set_time_widget_resign(LauncherSettings *settings, void *context) {
+void set_time_face_resign(LauncherSettings *settings, void *context) {
(void) settings;
(void) context;
watch_set_led_off();
diff --git a/movement/watch_faces/settings/set_time_face.h b/movement/watch_faces/settings/set_time_face.h
new file mode 100644
index 00000000..0c34d6b2
--- /dev/null
+++ b/movement/watch_faces/settings/set_time_face.h
@@ -0,0 +1,18 @@
+#ifndef SET_TIME_FACE_H_
+#define SET_TIME_FACE_H_
+
+#include "movement.h"
+
+void set_time_face_setup(LauncherSettings *settings, void ** context_ptr);
+void set_time_face_activate(LauncherSettings *settings, void *context);
+bool set_time_face_loop(LauncherEvent event, LauncherSettings *settings, void *context);
+void set_time_face_resign(LauncherSettings *settings, void *context);
+
+#define set_time_face { \
+ set_time_face_setup, \
+ set_time_face_activate, \
+ set_time_face_loop, \
+ set_time_face_resign, \
+}
+
+#endif // SET_TIME_FACE_H_
diff --git a/movement/widgets/clock/simple_clock_widget.h b/movement/widgets/clock/simple_clock_widget.h
deleted file mode 100644
index 3bf4c9a3..00000000
--- a/movement/widgets/clock/simple_clock_widget.h
+++ /dev/null
@@ -1,20 +0,0 @@
-#ifndef SIMPLE_CLOCK_WIDGET_H_
-#define SIMPLE_CLOCK_WIDGET_H_
-
-#include "movement.h"
-
-void simple_clock_widget_setup(LauncherSettings *settings, void ** context_ptr);
-void simple_clock_widget_activate(LauncherSettings *settings, void *context);
-bool simple_clock_widget_loop(LauncherEvent event, LauncherSettings *settings, void *context);
-void simple_clock_widget_resign(LauncherSettings *settings, void *context);
-
-uint8_t simple_clock_widget_get_weekday(uint16_t day, uint16_t month, uint16_t year);
-
-#define simple_clock_widget { \
- simple_clock_widget_setup, \
- simple_clock_widget_activate, \
- simple_clock_widget_loop, \
- simple_clock_widget_resign, \
-}
-
-#endif // FAKE_WIDGET_H_ \ No newline at end of file
diff --git a/movement/widgets/complications/pulseometer_widget.h b/movement/widgets/complications/pulseometer_widget.h
deleted file mode 100644
index e5947660..00000000
--- a/movement/widgets/complications/pulseometer_widget.h
+++ /dev/null
@@ -1,24 +0,0 @@
-#ifndef PULSEOMETER_WIDGET_H_
-#define PULSEOMETER_WIDGET_H_
-
-#include "movement.h"
-
-typedef struct {
- bool measuring;
- int16_t pulse;
- int16_t ticks;
-} PulsometerState;
-
-void pulseometer_widget_setup(LauncherSettings *settings, void ** context_ptr);
-void pulseometer_widget_activate(LauncherSettings *settings, void *context);
-bool pulseometer_widget_loop(LauncherEvent event, LauncherSettings *settings, void *context);
-void pulseometer_widget_resign(LauncherSettings *settings, void *context);
-
-#define pulseometer_widget { \
- pulseometer_widget_setup, \
- pulseometer_widget_activate, \
- pulseometer_widget_loop, \
- pulseometer_widget_resign, \
-}
-
-#endif // PULSEOMETER_WIDGET_H_ \ No newline at end of file
diff --git a/movement/widgets/settings/preferences_widget.h b/movement/widgets/settings/preferences_widget.h
deleted file mode 100644
index 3d463027..00000000
--- a/movement/widgets/settings/preferences_widget.h
+++ /dev/null
@@ -1,18 +0,0 @@
-#ifndef PREFERENCES_WIDGET_H_
-#define PREFERENCES_WIDGET_H_
-
-#include "movement.h"
-
-void preferences_widget_setup(LauncherSettings *settings, void ** context_ptr);
-void preferences_widget_activate(LauncherSettings *settings, void *context);
-bool preferences_widget_loop(LauncherEvent event, LauncherSettings *settings, void *context);
-void preferences_widget_resign(LauncherSettings *settings, void *context);
-
-#define preferences_widget { \
- preferences_widget_setup, \
- preferences_widget_activate, \
- preferences_widget_loop, \
- preferences_widget_resign, \
-}
-
-#endif // PREFERENCES_WIDGET_H_ \ No newline at end of file
diff --git a/movement/widgets/settings/set_time_widget.h b/movement/widgets/settings/set_time_widget.h
deleted file mode 100644
index 363fd571..00000000
--- a/movement/widgets/settings/set_time_widget.h
+++ /dev/null
@@ -1,18 +0,0 @@
-#ifndef SET_TIME_WIDGET_H_
-#define SET_TIME_WIDGET_H_
-
-#include "movement.h"
-
-void set_time_widget_setup(LauncherSettings *settings, void ** context_ptr);
-void set_time_widget_activate(LauncherSettings *settings, void *context);
-bool set_time_widget_loop(LauncherEvent event, LauncherSettings *settings, void *context);
-void set_time_widget_resign(LauncherSettings *settings, void *context);
-
-#define set_time_widget { \
- set_time_widget_setup, \
- set_time_widget_activate, \
- set_time_widget_loop, \
- set_time_widget_resign, \
-}
-
-#endif // SET_TIME_WIDGET_H_
diff --git a/movement/movement.c b/movement/movement.c
index 9c15833c..3417345c 100644
--- a/movement/movement.c
+++ b/movement/movement.c
@@ -6,7 +6,7 @@
#include "movement_config.h"
LauncherState movement_state;
-void * widget_contexts[MOVEMENT_NUM_WIDGETS];
+void * watch_face_contexts[MOVEMENT_NUM_FACES];
const int32_t movement_screensaver_deadlines[8] = {INT_MAX, 3600, 7200, 21600, 43200, 86400, 172800, 604800};
LauncherEvent event;
@@ -33,13 +33,13 @@ void movement_illuminate_led() {
movement_state.light_ticks = 3;
}
-void movement_move_to_widget(uint8_t widget_index) {
- movement_state.widget_changed = true;
- movement_state.next_widget = widget_index;
+void movement_move_to_face(uint8_t watch_face_index) {
+ movement_state.watch_face_changed = true;
+ movement_state.next_face = watch_face_index;
}
-void movement_move_to_next_widget() {
- movement_move_to_widget((movement_state.current_widget + 1) % MOVEMENT_NUM_WIDGETS);
+void movement_move_to_next_face() {
+ movement_move_to_face((movement_state.current_watch_face + 1) % MOVEMENT_NUM_FACES);
}
void app_init() {
@@ -59,8 +59,8 @@ void app_setup() {
static bool is_first_launch = true;
if (is_first_launch) {
- for(uint8_t i = 0; i < MOVEMENT_NUM_WIDGETS; i++) {
- widget_contexts[i] = NULL;
+ for(uint8_t i = 0; i < MOVEMENT_NUM_FACES; i++) {
+ watch_face_contexts[i] = NULL;
is_first_launch = false;
}
}
@@ -79,11 +79,11 @@ void app_setup() {
movement_request_tick_frequency(1);
- for(uint8_t i = 0; i < MOVEMENT_NUM_WIDGETS; i++) {
- widgets[i].setup(&movement_state.movement_settings, &widget_contexts[i]);
+ for(uint8_t i = 0; i < MOVEMENT_NUM_FACES; i++) {
+ watch_faces[i].setup(&movement_state.movement_settings, &watch_face_contexts[i]);
}
- widgets[0].activate(&movement_state.movement_settings, widget_contexts[0]);
+ watch_faces[0].activate(&movement_state.movement_settings, watch_face_contexts[0]);
event.subsecond = 0;
event.event_type = EVENT_ACTIVATE;
}
@@ -96,18 +96,18 @@ void app_wake_from_sleep() {
}
bool app_loop() {
- if (movement_state.widget_changed) {
+ if (movement_state.watch_face_changed) {
if (movement_state.movement_settings.bit.button_should_sound) {
- // low note for nonzero case, high note for return to widget 0
- watch_buzzer_play_note(movement_state.next_widget ? BUZZER_NOTE_C7 : BUZZER_NOTE_C8, 50);
+ // low note for nonzero case, high note for return to watch_face 0
+ watch_buzzer_play_note(movement_state.next_face ? BUZZER_NOTE_C7 : BUZZER_NOTE_C8, 50);
}
- widgets[movement_state.current_widget].resign(&movement_state.movement_settings, widget_contexts[movement_state.current_widget]);
- movement_state.current_widget = movement_state.next_widget;
+ watch_faces[movement_state.current_watch_face].resign(&movement_state.movement_settings, watch_face_contexts[movement_state.current_watch_face]);
+ movement_state.current_watch_face = movement_state.next_face;
watch_clear_display();
- widgets[movement_state.current_widget].activate(&movement_state.movement_settings, widget_contexts[movement_state.current_widget]);
+ watch_faces[movement_state.current_watch_face].activate(&movement_state.movement_settings, watch_face_contexts[movement_state.current_watch_face]);
event.subsecond = 0;
event.event_type = EVENT_ACTIVATE;
- movement_state.widget_changed = false;
+ movement_state.watch_face_changed = false;
}
// If the LED is off and should be on, turn it on
@@ -144,7 +144,7 @@ bool app_loop() {
// as long as screensaver_ticks is -1 (i.e. screensaver is active), we wake up here, update the screen, and go right back to sleep.
while (movement_state.screensaver_ticks == -1) {
event.event_type = EVENT_SCREENSAVER;
- widgets[movement_state.current_widget].loop(event, &movement_state.movement_settings, widget_contexts[movement_state.current_widget]);
+ watch_faces[movement_state.current_watch_face].loop(event, &movement_state.movement_settings, watch_face_contexts[movement_state.current_watch_face]);
watch_enter_shallow_sleep(true);
}
// as soon as screensaver_ticks is reset by the extwake handler, we bail out of the loop and reactivate ourselves.
@@ -158,7 +158,7 @@ bool app_loop() {
if (event.event_type) {
event.subsecond = movement_state.subsecond;
- can_sleep = widgets[movement_state.current_widget].loop(event, &movement_state.movement_settings, widget_contexts[movement_state.current_widget]);
+ can_sleep = watch_faces[movement_state.current_watch_face].loop(event, &movement_state.movement_settings, watch_face_contexts[movement_state.current_watch_face]);
event.event_type = EVENT_NONE;
event.subsecond = 0;
}
diff --git a/movement/movement.h b/movement/movement.h
index 025a5aa6..719a3d95 100644
--- a/movement/movement.h
+++ b/movement/movement.h
@@ -23,9 +23,9 @@ typedef union {
typedef enum {
EVENT_NONE = 0, // There is no event to report.
- EVENT_ACTIVATE, // Your widget is entering the foreground.
- EVENT_TICK, // Most common event type. Your widget is being called from the tick callback.
- EVENT_SCREENSAVER, // Your widget is being asked to display its output for screensaver mode.
+ EVENT_ACTIVATE, // Your watch face is entering the foreground.
+ EVENT_TICK, // Most common event type. Your watch face is being called from the tick callback.
+ EVENT_SCREENSAVER, // Your watch face is being asked to display its output for screensaver mode.
EVENT_LIGHT_BUTTON_DOWN, // The light button has been pressed, but not yet released.
EVENT_LIGHT_BUTTON_UP, // The light button was pressed and released.
EVENT_LIGHT_LONG_PRESS, // The light button was held for >2 seconds, and released.
@@ -42,26 +42,26 @@ typedef struct {
uint8_t subsecond;
} LauncherEvent;
-typedef void (*movement_widget_setup)(LauncherSettings *settings, void ** context_ptr);
-typedef void (*movement_widget_activate)(LauncherSettings *settings, void *context);
-typedef bool (*movement_widget_loop)(LauncherEvent event, LauncherSettings *settings, void *context);
-typedef void (*movement_widget_resign)(LauncherSettings *settings, void *context);
+typedef void (*watch_face_setup)(LauncherSettings *settings, void ** context_ptr);
+typedef void (*watch_face_activate)(LauncherSettings *settings, void *context);
+typedef bool (*watch_face_loop)(LauncherEvent event, LauncherSettings *settings, void *context);
+typedef void (*watch_face_resign)(LauncherSettings *settings, void *context);
typedef struct {
- movement_widget_setup setup;
- movement_widget_activate activate;
- movement_widget_loop loop;
- movement_widget_resign resign;
-} WatchWidget;
+ watch_face_setup setup;
+ watch_face_activate activate;
+ watch_face_loop loop;
+ watch_face_resign resign;
+} WatchFace;
typedef struct {
// properties stored in BACKUP register
LauncherSettings movement_settings;
// transient properties
- int16_t current_widget;
- int16_t next_widget;
- bool widget_changed;
+ int16_t current_watch_face;
+ int16_t next_face;
+ bool watch_face_changed;
// LED stuff
uint8_t light_ticks;
@@ -81,8 +81,8 @@ typedef struct {
uint8_t subsecond;
} LauncherState;
-void movement_move_to_widget(uint8_t widget_index);
-void movement_move_to_next_widget();
+void movement_move_to_face(uint8_t watch_face_index);
+void movement_move_to_next_face();
void movement_illuminate_led();
void movement_request_tick_frequency(uint8_t freq);